[![pipeline status](https://jugit.fz-juelich.de/network-science-group/emipy/badges/dev/pipeline.svg)](https://jugit.fz-juelich.de/network-science-group/emipy/-/commits/dev)
[![coverage report](https://jugit.fz-juelich.de/network-science-group/emipy/badges/dev/coverage.svg)](https://jugit.fz-juelich.de/network-science-group/emipy/-/commits/dev)
[![PyPI version](https://img.shields.io/pypi/v/emipy.svg)](https://pypi.org/project/emipy/)
[![Documentation build status](https://img.shields.io/readthedocs/emipy.svg)](https://readthedocs.org/projects/emipy/builds/)
![Python version](https://img.shields.io/pypi/pyversions/emipy.svg)
![LICENSE](https://img.shields.io/pypi/l/emipy.svg)

# About
emipy is a package for processing data of pollutant releases and pollutant transfers.
It's main target is to enable a fast output of individual data set requests and to provide visualisation options.

The data are provided by the [European Environment Agency](https://www.eea.europa.eu/data-and-maps/data/member-states-reporting-art-7-under-the-european-pollutant-release-and-transfer-register-e-prtr-regulation-23) and [Eurostat](https://ec.europa.eu/eurostat/de/web/gisco/overview).

# Documentation
For the documentation take a look over [here](https://emipy.readthedocs.io/en/latest/).

# Contribution
We are happy about ideas for new features or concrete implementations in emipy. 
Just get in touch and we will hopefully work together on your subject ASAP.

To contribute changes:

1. Fork the project on GitLab
2. Create a feature branch to work in your fork
3. Commit your changes to the feature branch
4. Push the branch to GitLab
5. Create a new pull request from the feature branch on GitLab

# Contact
For contact write a mail to p.boettcher@fz-juelich.de
